#
# spec file for package haruna
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           haruna
Version:        1.4.0
Release:        bp160.1.1
Summary:        Video player built with Qt/QML on top of libmpv
License:        CC-BY-4.0 AND GPL-3.0-or-later AND WTFPL
URL:            https://apps.kde.org/haruna
Source0:        https://download.kde.org/stable/haruna/%{version}/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/haruna/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        haruna.keyring
BuildRequires:  cmake >= 3.15
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf6-extra-cmake-modules >= 6.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(Breeze)
%if 0%{?suse_version} > 1500
BuildRequires:  cmake(KDSingleApplication-qt6)
%endif
BuildRequires:  cmake(KF6ColorScheme) >= 6.0.0
BuildRequires:  cmake(KF6Config)
BuildRequires:  cmake(KF6CoreAddons)
BuildRequires:  cmake(KF6Crash)
BuildRequires:  cmake(KF6DocTools)
BuildRequires:  cmake(KF6FileMetaData)
BuildRequires:  cmake(KF6I18n)
BuildRequires:  cmake(KF6IconThemes)
BuildRequires:  cmake(KF6KIO)
BuildRequires:  cmake(KF6Kirigami)
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(MpvQt)
BuildRequires:  cmake(Qt6Core) >= 6.6.0
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil) >= 58.29.100
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(mpv)
Requires:       kf6-breeze-icons
Requires:       yt-dlp

%description
Haruna is a video player built with Qt/QML on top of libmpv.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 \
  -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON

%kf6_build

%install
%kf6_install

%find_lang %{name}

# remove oddly-sized icons
rm -r %{buildroot}%{_kf6_iconsdir}/hicolor/44x44 \
      %{buildroot}%{_kf6_iconsdir}/hicolor/150x150 \
      %{buildroot}%{_kf6_iconsdir}/hicolor/310x310

%files
%license LICENSES/CC-BY-4.0.txt LICENSES/GPL-3.0-or-later.txt
%doc README.md
%{_kf6_bindir}/%{name}
%{_kf6_applicationsdir}/org.kde.haruna.desktop
%{_kf6_iconsdir}/hicolor/*/apps/haruna.*g
%{_kf6_appstreamdir}/org.kde.haruna.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Wed Apr 16 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.4.0
  Features:
  * Added setting to search subtitles recursively. Searches
    folders relative to the parent folder of the playing file and
    folders defined by the `Load subtitles from` setting
  * Added support for opening youtube playlists from urls
    containing a playlist id
  * Added actions to rotate video clockwise (ctrl + r) and
    counter clockwise (ctrl + e)
  Bugfixes:
  * Fix tracks menus showing tracks from previously opened files
  * Fix subtitles added by drag and drop not being added to the
    subtitles menu
  * While the progress/seek slider is pressed the video is
    paused, fixes continuously opening the next video when
    dragged and held all the why to the end
* Tue Feb 25 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.3
  Bugfixes:
  * Fixed app not getting focused when opening a file while
    single instance is enabled and player is open
  * Fixed overlapping the window title with the duration info in
    the footer
* Thu Jan 23 2025 pallas wept <pallaswept@proton.me>
- Update to version 1.3.2
  Bugfixes:
  * Fixed shortcuts not working with non english system language
  * Fixed restoring playback position
- Update to version 1.3.1
  Bugfixes:
  * Fixed screen inhibition not working
  * Fixed setting volume through mpris2
* Fri Jan 17 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.3.0
  Features:
  * Changed the settings related to restoring the playback
    position, if you changed the defaults you might have to redo
    them
  * Playlist: added context menu entries for non local urls to
    be opened in the browser and to be removed (from the
    playlist)
  * Added setting (in General) to start app in fullscreen
  * Added setting (in Subtitles) to control subtitle auto
    selection
  * Changed left and right mouse button default actions: left
    click is now play/pause and right click opens the context
    menu. Actions can be changed in settings Mouse page
  * Dragging the seek/progress bar will update the main view as
    well as the seekbar preview
  * Decreased the minimum window size
  * Replaced hardware decoding checkbox with an option in the
    hardware decoding combobox/drop-down
  Bugfixes:
  * Improved scrolling performance of playlist, shortcuts and
    seekbar's chapters menu
  * Fixed issue with setting shortcuts with modifier keys (ctrl,
    alt etc.)
  * Fixed active audio and subtitle tracks not being correctly
    checked
  * Removed empty header toolbar from settings window
  * Fixed a bug where the app would freeze when loading a file
    with lots of tracks
  * Improved menubar animation
  * The floating footer now hides when the mouse leaves the app
* Fri Sep 27 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.1
  Bugfixes:
  * Fixed thumbnail preview popup not resizing after disabling
    the previews
  * Use the same volume component for both footer styles
* Tue Aug 27 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2.0
  Features:
  * Added floating footer/bottom toolbar style
  * Removed the docbook and moved its content to tooltips
  * Middle clicking the playlist scrolls to the playing item
* Fri Jun 21 2024 Christophe Marin <christophe@krop.fr>
- Use the kf6-filesystem variables and macros
* Mon Jun  3 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.2
  Bugfixes:
  * Disabled track selection menus and buttons when there are no
    tracks to be selected
  * Fixed custom command toggling
  * Re-added "Scroll to playing item" and "Trash file" options
    to playlist context menu, lost during Qt6 port
  * Fixed some mpv properties not being correctly set at startup
* Mon May 20 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.1
  Bugfixes:
  * Subtitles menu not including manually added subtitles
  * Duration in the playlist being 0
  * Preview popup being visible for audio files
  * AB loop not resetting
- Use g++ 13 on Leap
* Fri Apr 19 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.0
  Features:
  * Setting to open playlist items with single click
  Bugfixes:
  * Video opening in a separate window when using mpv version
    0.38.0
  * Mute reseting when opening a new file
  * Playing item in playlist is no longer bold, it made text
    hard to read under certain conditions
* Tue Mar 26 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.2
  Bugfixes:
  * Hiding/showing Playlist toolbar setting
  * Track sub-menus in Audio and Subtiles global menus being
    empty
  * Freeze when opening HamburgerMenu
* Thu Mar 14 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.1
  * Ported to Qt6.
  * Some hwdec options have been removed, if needed they can be
    set in the settings under "Custom commands" as `set hwdec
    decoding_method_name` and choose "Run at startup"
  Features:
  * Opening items from the playlist should be faster
  Bugfixes:
  * Opening file through "Open File" action was not playing the
    file
  * Opening playlist file from playlist header was not doing
    anything
  * If "Maximum recent files" setting is set to zero the recent
    files are removed from the config file
* Thu Nov 16 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.3
  Bugfixes:
  * Fixed subtitle chooser dialog not opening in the folder the
    current playing file is in
  * Fixed playlist covering the footer/bottom toolbar and making
    it hard to close the playlist when toggling it with the mouse
    is turned off
  * Fixed clearing the playlist not working
  * Fixed url not being added to recent files when opened
    through the "Open Url" action
  Features:
  * Added "Escape" shortcut to close the settings window
* Fri Nov  3 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.2
  Bugfixes:
  * Don't show preview popup when no filee is loaded or when
    playing an online video
  * Fixed thumbnails not working in the playlist
* Thu Aug 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.12.1
  * Fixed file being paused on startup in certain cases
  * Fixed text color of the progress bar tooltip (kde#473784)
  * Fixed move video up/down and decrease subtitle font size
    actions (kde#473906, kde#473962)
  * Fixed playlist opening on top of the video when the overlay
    setting is turned off
* Fri Aug 25 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.12.0
  Features:
  * Added preview thumbnail to the progress bar, can be
    configured in the general settings page
  * Added setting to allow only a single instance, can be
    configured in the general settings page
  * Added action selection popup where you can search all
    available actions and trigger them (open with Ctrl+`
    (backtick), similar to KCommandBar)
  * Added setting to auto resize window to the video resolution,
    on Wayland the maximum size is not constrained
  * Added setting to hide playlist toolbar
  * Added menu item for each settings page under settings menu
  * The screenshot path is shown in the osd when using mpv
    0.36.0 or later versions
  * Added a "Scroll to playing item" entry to the playlist
    context menu
  * Added a "Open url" entry to the playlist context menu for
    online url
  * Hiding/showing the menubar, top toolbar and bottom toolbar
    is now animated
  * Added track selection menu entries to the hamburger menu
  Bugfixes:
  * Fixed not blocking inhibition (turning the display off,
    sleep etc.) during playback
* Thu Jul 13 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.11.3
  Bugfixes:
  * Fixed color picker buttons in subtitles settings not
    reflecting the current color
  * Fixed subtitles color changes not applying immediately
* Sun Jul  9 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.11.2
  Bugfixes:
  * Fixed osd not showing
  * Fixed adding items to the playlist
  * Fixed wrong values being shown in the osd
  * Fixed subtitle font size setting not being loaded from config
  * Fixed progress bar changing size when not using a
    monospaced/fixed-width font
  * Fixed footer/bottom toolbar not hiding when moving to the
    monitor below, while Haruna is in fullscreen
* Mon May 29 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.11.1
  Bugfixes:
  * Fixed quit action not working
  * Fixed osd not showing
  * Fixed playlist repeating when the repeat setting was turned
    off
* Mon May 15 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.11.0
  * PlayList: close context menu when playlist hides
  * flatpak: update manifest
  * mpvitem: initialize m_playlistModel before
    m_playlistProxyModel
  * hide mpv logging setting
  * mpvabstractitem: delete mpv controller when thread finishes
    and destroy mpv last
  * mpvitem: if property is not in cache get it and cache it
  * GIT_SILENT Sync po/docbooks with svn
  * PlayListItem(Compact/WithThumbnail): re add isLocal property
  * FileMenu: close menu after clicking an item in the recent
    files submenu
  * VideoSettings: fix screenshot format not working and add
    support for JPEG XL
  * PlaybackSettings: reorganize settings related to resuming
    playback
  * DebugSettings: set text only if files exists
  * application: add methods to check if a path or url exist
  * global: don't check if file exists, they don't on first run
  * mpvabstractitem: add expandText method
  * MpvVideo: activate the osd before a potential early return
  * footer: fix not showing in fullscreen and add a property to
    hold the mpv item
  * mpvabstractitem: stop listening to mpv events and call
    m_workerThread->wait()
  * mpvitem: remove parent from models
  * mpvitem: set m_formattedDuration when duration changes
  * use QStringLiteral everywhere
  * mpvcontroller: use QString::fromStdString
  * mpvcontroller: include clocale
  * playlistmodel: openM3uFile(): stop search for last played
    file after 1st match
  * CustomCommandsSettings: improve looks and functionality of
    disabled commands
  * VolumeSlider: change mpv volume only on when clicking
  * mpvitem: make connection queued and get more properties from
    the cache
  * application: move window geometry saving to the worker class
  * Osd: check if text is null or undefined
  * PlayListItem, PlayListItemCompact: remove unnecessary
    properties
  * PlayListItemWithThumbnail: remove unnecessary properties and
    change fill mode
  * Actions: remove unused property
  * MpvVideo: remove unused properties
  * MpvVideo: loading indicator: make color solid and lower
    opacity
  * mpv: move position saving timer to c++
  * Actions: get volume from cache
  * mpv: use a single signal for all properties
  * mpvabstractitem: use queued connections to talk to the
    controller
  * mpvitem: add new properties
  * PlayList: increase animation duration
  * mpvabstractitem: m_workerThread don't call wait in destructor
  * mpris2: remove a connection
  * mpvitem: refactor position, duration and remaining properties
  * mpv: setup connections between MpvController and MpvItem
  * mpv: split MpvController and MpvAbstractItem in separate
    files and clean up code
  * refactor mpv
  * KAboutData: don't set data in constructor
  * SVN_SILENT made messages (.desktop file) - always resolve
    ours
  * playlistmodel: openFile: set url scheme to "file" when
    dealing with local files
  * MpvVideo: onReady: use proxy model to get the items
  * MpvVideo: onReady: convert url to string in if statement
  * MpvVideo: use proxy model to get the next item to play on EOF
  * mpvitem: don't emit `..Changed` signals when setting certain
    properties
  * Fix minor typo
  * actionsmodel: make text capitalization consistent
  * playlistmodel: fix not being able to open .rm files
  * mpris2: add support for `Raise` method
  * mpvitem: make none track text translatable
  * Settings: ensure text field settings are properly saved
  * SubtitlesSettings: fix accessing allowOnBlackBorders
  * mpv: only resume playback after unminimizing if playback was
    active before
  * main.qml: move some components
  * menubar: remove id and background properties
  * disable global menu on Windows
  * use QUrl::fromUserInput to construct QUrl
  * playlistmodel: fix file opening
  * Revert "change Application::mimeType to take a QString"
  * Revert "add File class for consistent local path handling"
  * add File class for consistent local path handling
  * change Application::mimeType to take a QString
  * Revert "playlistmodel: PlayListModel::openFile: pass percent
    encoded path to QUrl"
  * playlistmodel: PlayListModel::openFile: pass percent encoded
    path to QUrl
  * DebugSettings: use Kirigami.ActionTextField
  * InputPopup: mention yt-dlp in message for missing yt-dlp or
    youtube-dl support
  * DebugSettings: disable buttons and explaing what it means
    when fields are empty
  * DebugSettings: change icon of buttons opening a file
  * rename InformationSettings to DebugSettings
  * add informationsettings.kcfg and informationsettings.kcfgc
  * Application::configFolderPath get the config folder path
  * InformationSettings: add setting to enable mpv logging
  * Settings: add Information page
  * application: refactor methods returning config folder/files
  * global: return empty QString if config folder/files don't
    exist
  * don't use width, height, Layout and anchors properties
    inside the component
  * main.qml: removve unused SystemPalette
  * PlayList: set width, height, x and y properties outside the
    component
  * HProgressBar: resize chapters popup width according to the
    longest chapter
  * Application::mimeType: set url scheme to `file` if empty
  * flatpak: update versions
  * bugs_and_feature_requests: remove a paragraph
* Sun Jan 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.3:
  * mpvitem: use loadFile() method on PlayListModel::playingItemChanged() signal
  * only link the KIO libs that are actualy used
  * Fix relative M3U loading
  * HProgressBar: refactor chapters menu into a popup with a listview
  * HProgressBar: add tooltip for 'Skip Chapter' checkbox in chapters popup
  * playlistmodel: getSiblingItems: use percent-encoded path with QUrl
* Wed Jan 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- No need to BuildRequire yt-dlp/youtube-dl: this is only a
  runtime dependency.
* Sat Jan  7 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.2
  Bugfixes:
  * Fixed crash when "Maximum recent files" setting was set to
    zero.
* Fri Jan  6 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.1
  Bugfixes:
  * Fixed not auto playing next file in playlist, when current
    file ends
  * Fixed opened file not playing when "Auto load videos from
    same folder" setting is disabled
* Tue Jan  3 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.0
  Features:
  * Playlist: added options to open m3u files (without support
    for extended attributes), add files and urls (only the url
    path will be displayed, no title and no duration), sort,
    clear and save the playlist
  * Playlist: added context menu for the playlist items
  * Playlist: added setting to remember playlist state
  * Subtitles: added setting to render subtitle in black borders
  * Video: added setting to set a default cover for music files
  * Added command line option to override the ytdl format
    selection setting (this option is overwritten if the GUI
    setting is changed)
  * Added MPRIS thumbnail
  Bugfixes:
  * Recent files: fixed ordering, showing duplicates, clearing
    and adding when list is full
  * Fixed OSD showing without text
  * Playlist: fixed "Increase font size when fullscreen" setting
    not working
  * Playlist: removed rowHeight setting
* Wed Oct 12 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.3
  * playlistmodel: set QUrl scheme if not set
  * actionsmodel: port QRegExp to QRegularExpression
  * only use Qt5X11Extras with qt5
  * cmake: add support for qt6
  * pass correct type to QMetaObject::invokeMethod
  * change emit to Q_EMIT
  * use a QUrl instead of a QString where a QUrl is expected
  * switch to Q_SIGNALS and Q_SLOTS
- Added lang subpackage
* Fri Oct  7 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.2
  * actionsmodel: change text of togglePlaylistAction action to
    just Playlist
  * recentfilesmodel: use custom implementation instead of
    KRecentFilesAction
  * window: use Kirigami gridUnit for width and height
  * mpv: move mpris connections to cpp
  * Settings: improve right to left behaviour
  * footer: fix play next/previous button icons in right to left
    mode
  * footer: fix seek bar and volume bar right to left behaviour
  * playlistmodel: use a QUrl to determine the mimetype
  * mpv: fix includes and call methods from MpvCore instead of
    MpvItem
  * Footer: improve font scaling
  * SubtitlesFolders: fix model name
  * settings: use qmlRegisterSingletonInstance instead of
    qmlRegisterSingletonType
  * Add a menu item in the Subtitles header button and menubar
    to open a subtitle file
  * CustomCommands: use `Kirigami.PlaceholderMessage` when there
    are no commands
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of
    ECM_MODULE_PATH
  * mpvitem: remove duplicated property
* Wed Aug 24 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.1
  Bugfixes:
  * Fixed two broken actions in the global menu
  * Fixed translations
* Mon Aug 22 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.0
  Features:
  * Refactored the shortcuts configuration, now it's available
    in the settings window with the other settings, instead of
    opening another window
  * Hamburger menu now only show a few actions, the rest are
    available in a submenu
  * When menubar is hidden the hamburger menu will be shown in
    the header/toolbar and when the header is hidden it's shown
    in the footer
  * Added a proper context menu for the video
  * Added setting to start playback when resuming playback of a
    file
  * Added setting to set maximum number of recent files
  * Added option to clear recent files
  * Added setting to restore window size and position
  * Added settings to customize the subtitle font family, size,
    style (bold, italic), color, shadow color, shadow offset,
    border color, border width
  * Moved seek settings to playback settings page
  * Moved volume step setting to audio settings page
  * Custom commands that run on startup can be turned off so
    they are not set on next run
  * In mouse settings the action text, which is translatable, is
    shown instead of it's internal name
  Bugfixes:
  * Toggling menubar and header/toolbar through actions
    remembers the state on next run
  * Restore time position for youtube videos
  * Improve mpv initialization to allow better hardware decoding
    support
  * Ytdl-format property can be overwritten by a custom command
    action
- Switch to yt-dlp where available
* Wed Apr 20 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.0
  * fix: wrong height for playlist items
  * Fix freezes on systems with slow disks
  * Fix build warnings and errors
  * fix: mark methods as override
  * chore: remove unused code
  * fix: load correct files and call functions from actions
    manager
  * fix: release date for 0.7.3
  * fix: don't run animation when component is hidden
  * SVN_SILENT made messages (.desktop file) - always resolve
    ours
  * GIT_SILENT made messages (after extraction)
  * fix: menubar not hiding in fullscreen
  * refactor: improvements to framedecoder
  * feat: add global menu support
  * fix: compile with MPV_CLIENT_API_VERSION 1 and 2
  * feat: add action to seek to watch later position
    (Ctrl+Shift+P)
  * feat: add action to restart playback (seek to 0/beginning,
    F5 key)
  * feat: add action to load last played file (Ctrl+Shift+L)
  * chore: add .directory to gitignore
  * fix: rename icons license files
  * fix(osd): when file can't be played show filename if there's
    no title
  * build: use ECMAddAppIcon module
  * feat: allow to control the time position saving interval
  * refactor: add Settings to settings qml file names
  * refactor: rename SettingsEditor to SettingsWindow
  * refactor: put settings window in a loader
  * build: add KDECMakeSettings and KDECompilerSettings
  * fix: get actions from actionsManager
  * chore: add license info to actionsmanager.cpp/h
  * refactor: move actions cpp code to its own class
  * fix: remove unused cursor hiding/showing code
  * fix(playlist): use position from PlaylistSettings
  * fix(playlist): set height to mpv height
  * fix(playlist): unable to close the playlist
  * feat(menu): add more actions
  * build: add header files to target_sources
  * chore: remove more unneeded code
  * chore: remove unneeded code
  * chore: remove id from repeater
  * feat: add menu to open recent files
  * build: add FindYtdlp.cmake file
  * Add i18n()
  * SVN_SILENT made messages (.desktop file) - always resolve
    ours
  * GIT_SILENT made messages (after extraction)
  * feat: Add setting to pause the player if minimized
  * fix(settigs): clarify remember time position settings
  * chore(settings): remove labels from .kcfg files
  * fix(settings): load subtitles folders correctly
- Drop haruna-mpv_v2_fix.patch (merged upstream)
* Sun Jan 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Add haruna-mpv_v2_fix.patch (fixes Factory build)
* Wed Nov  3 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.3
  * fix(settings): load icon in settings page
  * fix: lower tooltip font size
  * fix: rename icon in desktop file
  * fix: install only one icon
  * fix(header): fix toolbutton menu not closing
  * feat(mpv): keep file loaded after eof is reached
  * Revert "fix: keep file loaded after reaching end of file"
  * feat(playlistmodel): add appendVideo method
  * fix(settings): raise window when clicking configure button
  * fix: keep file loaded after reaching end of file
  * fix(settings): load correct file for the General page
  * fix: report bug button in about page not working
  * fix(youtube-dl): prioritize yt-dlp
  * fix(icon): install haruna.svg icon
  * fix(mpris): only show filename if there's no title
  * refactor(Settings): add about page and move navigation code
    in settings editor
  * Extract messages for configuration keys
  * refactor(Settings): move actions inside list view
  * fix(Settings): make sidebar elements translatable
* Sun Sep 26 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.2
  * fix(PlayListItem): set correct height
  * GIT_SILENT made messages (after extraction)
  * fix: make mouse action filtering case insensitive
  * fix: change how cursor is hidden in fullscreen
  * Delete FUNDING.yml
  * Update README.md
  * Settings: dont open window at startup
* Mon Sep 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.1
  * Settings window: decrease width
  * Settings: use Kirigami gridUnit for width and height
  * Settings: remove page before pushing another one
  * Fix video repeating when repeat is turned off
  * Remove quit button from toolbar
  * Fix play/pause button being disabled when it shouldn't
  * Change resume playback setting into 2 settings
  * PlayListItem: remove id
  * PlayList: remove ids from playlist items
  * Install icon in the correct path
- Drop haruna-icon_path.patch and haruna-playlist_noid.patch
  (merged upstream)
* Mon Aug 23 2021 Luigi Baldoni <aloisio@gmx.com>
- Add haruna-icon_path.patch and haruna-playlist_noid.patch
  (backported fixes)
* Fri Aug 20 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.0 (see changelog at
  https://invent.kde.org/multimedia/haruna/-/compare/0.6.3...v0.7.0
* Wed Apr 28 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.3
  * Set breeze icon theme before QApplication creation
* Sat Apr 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.2
  * MpvObject: set youtube-dl format before loading file
  * Bundle ssl certs from certify
* Wed Apr  7 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.1
  * Update desktop file
  * add link to flathub page
  * MpvObject
  * Playlist model
* Wed Mar 31 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.0
  * Remove color schemes until their license is clear
  * MPVObject: show loading indicator for all videos
  * Disable next/previous buttons when there's 1 or no video in
    the playlist
  * Add youtube-dl to dependencies list
  * Don't use breeze icons by default
  * GUI style
  * Add copyrights
  * Correct copyright and license for cmake/FindLibmpv.cmake
  * MenuBar
  * Add checks before trying to access data
  * MpvObject
  * PlaylistModel: avoid index out of range error
  * Audio/Subtitles settings
  * Always open first video in new youtube playlist
  * Remove wrong license files
  * Add license to files without one
  * Skip videos that can't be played
  * Add loading indicator for youtube videos
  * If youtube-dl is not available display a message instead of
    the controls to open a url
  * PlayListItemWithThumbnail change elide mode to
    WrapAtWordBoundaryOrAnywhere
  * Add dependencies and build instructions to readme file
  * Youtube playlist
  * PlaylistItem
  * Worker::getMetaData return if there's no extractor available
  * CMake
  * Make mpris player dbus interface a qml context property
  * Add mpris2 support
  * Fix play next/prev actions not updating the LastPlayedFile
  * Use LabelWithTooltip without prefix
  * Add placeholder and tooltip for 'Skip chapters' feature Add
    help for 'Remember time position' and 'Skip chapters' features
  * Refactor time position saving
  * Rename custom label component to LabelWithTooltip
  * MpvObject: fix cursor not hiding in fullscreen
  * MpvObject: resume playback changes
  * Settings: don't togggle hw decoding with save file position
    checkbox
  * Update README.md
  * Add FUNDING.yml
  * Settings: change default screenshots folder
  * MpvObject: add resume/restart video popup
  * Settings: add option to disable file position saving and
    resuming
  * MpvObject: update tracks models when mpv's track-list changes
  * Remove console.log
  * MpvObject: allow loading subtitles through drag and drop
  * MpvObject: allow to print the error in get/setProperty
    methods
  * MpvObject: move loadFile function to the cpp side
  * Application: make getFileContent parameter const
  * MpvObject
  * MpvObject
  * main.qml: fix mpv.scrollPositionTimer ->
    playList.scrollPositionTimer
  * Generate AppImage from every build (#43)
  * Settings
  * Update help for old Breeze style option to fit the changes
  * Settings: remove notice about Breeze not being installed
  * SettingsBasePage: replace i18n with qsTr
  * MpvObject: fix next file not loading when current file
    finishes
  * Playback Settings
  * Remove wrong and unused id
  * Use add command to change volume and speed properties Set
    max volume to 100
  * CMake: make set_package_properties more compact
  * Seetings navigation: Set padding for each side, fix for Qt
    5.12
  * Register PlayListModel type for qml usage
  * CMake: add FindLibmpv.cmake file
  * Add liberapay and paypal donation links
  * Refactor file loading code
  * application.h: reorder some functions, remove some unused
    code
  * Refactor youtube playlist code
  * MpvObject: comment code in getYouTubePlaylist
  * Thumbnail image provider: provide generic icon for urls
  * MpvObject: extract youtube playlist code to function
  * Refactor to allow opening youtube playlists through "Open
    Url"
  * Show osd message when toggling deinterlacing
  * Header: use only one RowLayout
  * Playlist: remove style property, use PlaylistSettings.style
  * Header: remove buttons to toggle playlist Footer: use
    loaders for the playlist toggle button
  * data/appdata.xml: Make validation successful
  * Add import path for qml components
  * Actions: rename "Toggle Playlist" to "Playlist"
  * MpvVideo: consider the playlist position when anchoring
  * Header, Footer: add another button to toggle the playlist,
    one on the left and one on the right coresponding to the
    playlist's position
  * Playlist: add compact style
  * Playlist: fix playlist items coloring
  * Playlist: add option to push video instead of overlaying it
  * Add button in the header and footer to toggle the playlist
    when toggling it with the mouse is disabled
  * MpvVideo: settings are in a window so ancoring to it is wrong
  * Settings: refactor mouse page
  * Settings: add custom component for images adjustments sliders
  * Setings: remove color adjustments page
  * SettingsHeader: add top margin
  * Settings: make casing consistent
  * Settings: remove unneeded properties
  * Refactor settings window
  * Make configure header button uncheckable Don't close
    settings window (if open) when going fullscreen
  * Add action to toggle video deinterlacing
  * Open settings in separate window
  * qthelper.h: fix build with Qt 5.12
- Drop haruna-0.5.0-Qt512_fix.patch (merged upstream)
* Wed Jan 20 2021 aloisio@gmx.com
- Add haruna-0.5.0-Qt512_fix.patch
* Mon Jan 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.0
  * Update about data
  * Playback settings: remove unnecesary layout
  * Refactor settings pages
  * Add SettingsHeader component
  * Settings: add option to toggle hardware decoding
  * MpvObject: move code from eventHandler to connections
  * Replace mpv_set_option_string with setProperty
  * mpvopbject.cpp: use const container in tracks loop, clazy
    range-loop
  * qthelper: remove deprecated functions
  * Emit signals when tracks change
  * Refactor audio and subtitle tracks model into properties
  * Remove unused code
  * Add emit before dataChanged signal
  * Settings: fix open config file and folder not working
  * Settings: add help page for general settings
  * Settings: check if the Breeze style is available,
  * Settings: split useBreezeTheme in two settings,
  * Save SkipChapters setting when changed from progress bar menu
  * Add option to set file dialog location
  * CMake: look for breeze, kirigami and qt5qml
  * Fix breeze icon theme name
  * Add option to use the breeze icon theme and GUI style
  * Link against KIconThemes
  * Fix video not playing when opened from playlist
  * CMake: remove REQUIRED from find_package
  * Use the new label component where appropriate
  * Add custom label component
* Wed Dec  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.2
  * Mouse Settings: use ListModel instead of array
  * Fix mouse actions
- Drop haruna-0.4.1-fix_mouse_actions.patch (merged upstream)
* Tue Dec  8 2020 aloisio@gmx.com
- Add haruna-0.4.1-fix_mouse_actions.patch
* Tue Dec  8 2020 aloisio@gmx.com
- Update to version 0.4.1
  * Fix build on Qt 5.12
  * Save last played file
  version 0.4.0:
  * Change back to qmlRegisterSingletonType
  * add some mimetypes and KDE file handlers (from mpv)
  * Use KConfig to handle settings
  * Fix crash when using the playPrevious action
  * Settings: fix ComboBox delegate width
  * Change back to Flickable for the help window
  * CMake: fix file paths
  * Add license files for color scheme files
  * CMake: fix target_include_directories paths
  * CMake: add option to install color schemes
  * CMake: use target_include_directories and update includes
  * Rename Settings folder to settings
  * CMake: use target_sources
  * Playlist: highlight playing video
  * Add option to switch between simple playlist items
  * Add PlayListItemWithThumbnail component
  * Add image provider for video thumbnails
- Drop haruna-0.3.1-fix_crash_wih_Qt512.patch
  and haruna-0.3.1-fix_version.patch (merged upstream)
* Fri Dec  4 2020 aloisio@gmx.com
- Add haruna-0.3.1-fix_crash_wih_Qt512.patch and
  haruna-0.3.1-fix_version.patch
* Tue Dec  1 2020 aloisio@gmx.com
- Update to version 0.3.1
  * Playlist: always hide horizontal scrollbar
  * Add include for QPointer in application.cpp
  * Fix includes in application.cpp
- Drop haruna-0.3.0-QPointer.patch (merged upstream)
* Tue Dec  1 2020 aloisio@gmx.com
- Update to version 0.3.0
  * Playlist: hide horizontal scrollbar
  * Cleanup Application constructor
  * Move code from main.cpp to application.cpp
  * Move qml type registration, thread, about data and
  * MPV: refactor loading file code
  * MPV: make pause property writable
  * Use ScrollView and TextArea for help pages
  * Pass all metadata from worker to playlist model
  * ProgressBar: Disable middle click when chapter markers are
    hidden
  * Add option to hide chapter markers
  * Fix menu and header toggle actions breaking binding of
    'visible' prop…
  * Add help menu with about haruna action
  * Add about action
  * Use KAboutData setters for more clarity
  * Remove feature_summary from src/CMakeLists.txt
  * Upper case fusion style name
  * Use mpv.command to load file from playlist
  * Add setting to disable adding videos from same folder to
    playlist
  * Add clear method to playlist model
  * Add playlistitem constructor and set its properties inside it
  * Play next action jumps to first video if current video is
  * Add setting to repeat playlist or stop after last video
    finished
  * Add watchPercentage property to mpv,
- Add haruna-0.3.0-QPointer.patch
* Mon Nov  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.2.2
  * Fixed incompatibilities with Qt 5.12
- Drop haruna-desktop.patch, haruna-qt512_1.patch and
  haruna-qt512_2.patch
* Wed Oct 14 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.2.1)
